@@ -311,6 +311,8 @@ def slope_induced_cont(data = None, contravariant = -1., lag = 2, slope_column =
     return contravariant*signal
 
 def counting_candles(data= None, threshold = 1., contravariant = -1., lag = 2, **kwargs):
+    data['close_diff']= (data.close.diff() >= 0.).astype(float)
+
     ## aggregating the volumes by lag
     data.index = range(0,len(data))
     all_indices = list(reversed(range(len(data) - 1, 0, -lag)))
@@ -321,10 +323,12 @@ def counting_candles(data= None, threshold = 1., contravariant = -1., lag = 2, *
     volumefrom = data.groupby(['aggregated_indice'])['volumefrom'].agg('sum')
     high = data.groupby(['aggregated_indice'])['high'].agg('max')
     low = data.groupby(['aggregated_indice'])['low'].agg('min')
+    close_diff = data.groupby(['aggregated_indice'])['close'].agg('sum')
 
     data['aggregated_volume'] =  data['aggregated_indice'].map(volumefrom)
     data['aggregated_high'] =  data['aggregated_indice'].map(high)
     data['aggregated_low'] =  data['aggregated_indice'].map(low)
+    data['aggregated_close_diff'] =  data['aggregated_indice'].map(close_diff)
 
     data = data[::-lag]
     data = data.iloc[::-1]
